@@ -1,5 +1,12 @@
 Kd.r <-
-function(X, r, ReferenceType, NeighborType, Weighted=FALSE) {
+function(X, r, ReferenceType, NeighborType, Weighted=FALSE, Original=TRUE) {
+  # Select the bandwith: original choice by Duranton and Overman or optimized one.
+  if (Original) {
+    bw = "nrd0"
+  } else {
+    bw = "sj"
+  }
+  
   # Compute the matrix of distances
   Dist <- pairdist.ppp(X)
   # Eliminate self point pair
@@ -15,9 +22,9 @@ function(X, r, ReferenceType, NeighborType, Weighted=FALSE) {
   if (Weighted) {
     Weights <- matrix(rep(X$marks$PointWeight, each=X$n), nrow=X$n)
     Weights <- Weights[IsReferenceType, IsNeighborType]
-    Density <- density(Dist, weights=Weights/sum(Weights), from=0, na.rm=TRUE)  
+    Density <- density(Dist, weights=Weights/sum(Weights), from=0, na.rm=TRUE, bw = bw)
   } else {
-    Density <- density(Dist, from=0, na.rm=TRUE)  
+    Density <- density(Dist, from=0, na.rm=TRUE, bw = bw)
   }  
   # Interpolate results at the chosen R
   return(approx(Density$x, Density$y, xout=r)$y)
